@@ -4,6 +4,8 @@ from ruamel.yaml import YAML
 from freemocap import recordingconfig
 from freemocap.webcam import timesync
 
+import cv2
+
 class Session: #self like "recording self"
     def __init__(self):
         
@@ -37,8 +39,17 @@ class Session: #self like "recording self"
         When starting a session from stage 1, create all the file paths necessary, and create a session dictionary to save settings.
         Calls the create_session_paths and create_session_dictionary function
         """         
-        dataFolderPath = self.basePath/self.dataFolderName
+        #dataFolderPath = self.basePath/self.dataFolderName
+     
+
+        if self.basePath.stem == self.dataFolderName: #don't recursively craete 'FreeMoCap_Data' folders!
+            dataFolderPath = self.basePath
+        else:
+            dataFolderPath = self.basePath/self.dataFolderName
+        
         dataFolderPath.mkdir(exist_ok= True)
+            
+    
 
         self.sessionPath = dataFolderPath/self.sessionID
         self.sessionPath.mkdir(exist_ok=True)
@@ -149,16 +160,61 @@ class Session: #self like "recording self"
         self.sessionPath = self.dataFolderPath/self.sessionID
         self.sessionPath.mkdir(exist_ok=True)
 
+
+        
         self.session_yaml_path = self.sessionPath/'{}_config.yaml'.format(self.sessionID)
 
-        if stage == 3:
-            #this is for the case of GoPro recordings/external recordings - if no config file exists, create one
-            if self.session_yaml_path.is_file():
-                self.session_settings = self.load_session()
-            else: 
-                self.start_session({},{})
-        else:
-            self.session_settings = self.load_session()
+        # if stage == 3:
+        #     #this is for the case of GoPro recordings/external recordings - if no config file exists, create one
+        #     if self.session_yaml_path.is_file():
+        #         self.session_settings = self.load_session()
+        #     else: 
+        #         self.start_session({},{})
+        #         #run a check to make sure all the frame numbers are the same 
+        #         a_sync_vid_path = list(self.syncedVidPath.glob('*.mp4'))
+        #         frames_per_cam = {} 
+               
+        #         for vid in a_sync_vid_path:
+        #             temp_cap = cv2.VideoCapture(str(vid))
+        #             thisCamFrames = temp_cap.get(cv2.CAP_PROP_FRAME_COUNT)
+        #             frames_per_cam[str(vid)] = thisCamFrames
+        #         temp_cap.release()
+        #         frame_check = len(list(set(list(frames_per_cam.values())))) == 1 # using set() to remove duplicates and check for values count
+                
+
+        #         if frame_check:
+        #             self.numFrames = int(thisCamFrames)
+        #             self.session_settings['recording_parameters'].update({'numFrames':self.numFrames})
+        #             self.numCams = len(a_sync_vid_path)
+        #         else:
+        #             print('The number of frames in each video are not equal. Frame counts are: ' + frames_per_cam)
+        # else:
+        #     self.session_settings = self.load_session()
+
+        if self.session_yaml_path.is_file():
+            self.session_settings = self.load_session() #if a yaml exists, load it in (this is the case for a webcam recording, or an external recording that's been processed already)
+        else: #if a session yaml doesn't exist, as is the case of an external recording
+            self.start_session({},{})
+            #run a check to make sure all the frame numbers are the same 
+            a_sync_vid_path = list(self.syncedVidPath.glob('*.mp4'))
+            frames_per_cam = {} 
+            
+            for vid in a_sync_vid_path:
+                temp_cap = cv2.VideoCapture(str(vid))
+                thisCamFrames = temp_cap.get(cv2.CAP_PROP_FRAME_COUNT)
+                frames_per_cam[str(vid)] = thisCamFrames
+            temp_cap.release()
+            frame_check = len(list(set(list(frames_per_cam.values())))) == 1 # using set() to remove duplicates and check for values count
+            
+
+            if frame_check:
+                self.numFrames = int(thisCamFrames)
+                self.session_settings['recording_parameters'].update({'numFrames':self.numFrames})
+                self.numCams = len(a_sync_vid_path)
+                self.session_settings['recording_parameters'].update({'numCams':self.numCams})
+                self.save_session()
+            else:
+                raise ValueError('The number of frames in each video are not equal. Frame counts per video are are: ' + str(frames_per_cam))
         
 
 
