@@ -3,6 +3,7 @@ import cv2
 import time
 import pickle
 import os
+import platform
 
 class CamRecordingThread(threading.Thread):
     def __init__(
@@ -48,10 +49,10 @@ def CamRecording(
     # necessary, since each webcam runs as it's own object.
     global flag
     flag = False
+    camWindowName = "RECORDING - " + str(camID)+' - Press ESC to exit'
+    cv2.namedWindow(camWindowName)  # name the preview window for the camera its showing
 
-    cv2.namedWindow(camID)  # name the preview window for the camera its showing
-
-    if os.name == 'nt': #use CAP_DSHOW for windows, CAP_ANY otherwise (*might* make things ubuntu/mac compatible, but not sure. See https://github.com/jonmatthis/freemocap/issues/52)
+    if platform.system() == 'Windows':
         cam = cv2.VideoCapture(camInput, cv2.CAP_DSHOW)
     else:
         cam = cv2.VideoCapture(camInput, cv2.CAP_ANY)
@@ -98,7 +99,7 @@ def CamRecording(
             break
         success, frame = cam.read()
 
-        cv2.imshow(camID, frame)
+        cv2.imshow(camWindowName, frame)
         frame_sized = cv2.resize(frame, (resWidth, resHeight))
         # frame_sized = frame
         out.write(frame_sized)
@@ -110,7 +111,7 @@ def CamRecording(
             with open(session.rawVidPath/camID, "wb") as f:
                 pickle.dump(timeStamps, f)  # dump the data
             break
-    cv2.destroyWindow(camID)
+    cv2.destroyWindow(camWindowName)
     return timeStamps
 
 
